#!/usr/bin/env python3

import asyncio

PORT = 1234

async def handle(reader, writer):
    addr = writer.get_extra_info('peername')
    print(f"Machine {addr!r} just connected.")

    while True:
        data = await reader.read(100)
        message = data.decode().strip()
        writer.write(data)
        await writer.drain()
        if message == "STOP":
            writer.write(b'Bye!\n')
            message = f"{addr!r} closed the connection."
            print(message)
            break

    writer.close()

async def main():
    # Listen on all interfaces and port number PORT
    server = await asyncio.start_server(handle, '', PORT)
    addr = server.sockets[0].getsockname()

    print(f'Serving on {addr}')
    async with server:
        await server.serve_forever()

asyncio.run(main())
